@@ -82,7 +82,9 @@ def classic_analysis(suceptibility,binder,correlation,L,rho,arr_q=[],arr_ql=[]):
 	try:
 		histogram_q=np.loadtxt('histogram_q.dat')
 		histogram_q_l=np.loadtxt('histogram_q_l.dat')
+		print('overlap histograms')
 		plot_histogram_q(histogram_q,arr_q)
+		print('link histograms')
 		plot_histogram_q_l(histogram_q_l,arr_ql)
 	except:
 		print('No histograms')
